@@ -32,7 +32,7 @@ fit
 
 ## ----coef---------------------------------------------------------------------
 fit %>%
-  select(arima) %>%
+  select(Region, State, Purpose, arima) %>%
   coef()
 
 ## ----glance-------------------------------------------------------------------
